# coding:utf-8

from urllib.parse import urljoin

__project__ = "xarg-python"
__version__ = "1.6.3"
__description__ = "Simple command-line tool based on argparse."
__urlhome__ = "https://github.com/bondbox/xarg-python/"
__urlcode__ = __urlhome__
__urldocs__ = __urlhome__
__urlbugs__ = urljoin(__urlhome__, "issues")

# author
__author__ = "Mingzhe Zou"
__author_email__ = "zoumingzhe@outlook.com"

# project name
__prog_name__ = "xarg"
__prog_complete__ = "xargcomplete"
__prog_project__ = "xargproject"
